Name:           angie
Version:        1.7.0
Release:        1%{?dist}
Summary:        Efficient, powerful and scalable reverse proxy and web server
License:        BSD-2-Clause
URL:            https://angie.software
Source0:        https://download.angie.software/files/%{name}-%{version}.tar.gz
Source1:        angie.conf
Source2:        default.conf
Source3:        example.conf
Source4:        angie.logrotate
Source5:        angie.service
Source6:        angie.upgrade
Source108:      wasm-micro-runtime-WAMR-1.3.2.tar.gz
Source109:      wasmtime-v25.0.0-x86_64-linux-c-api.tar.xz
Source110:      angie-wasm-v0.1-beta4.tar.gz
Source111:      README-module-wamr
Source112:      README-module-wasmtime
Source113:      README-module-wasm




BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  openssl-devel
BuildRequires:  pcre2-devel
BuildRequires:  zlib-devel

Requires:       systemd

%description
Actively developing fork of nginx aiming to keep it great
with brand new extra functionality.

%prep
rm -Rf %{_builddir}/*
%setup -q
tar -xpzf %{_sourcedir}/wasm-micro-runtime-WAMR-1.3.2.tar.gz -C %{_builddir}
tar -xpJf %{_sourcedir}/wasmtime-v25.0.0-x86_64-linux-c-api.tar.xz -C %{_builddir}
tar -xpzf %{_sourcedir}/angie-wasm-v0.1-beta4.tar.gz -C %{_builddir}

cp -Rp %{_builddir}/angie-%{version} %{_builddir}/angie-debug

%build
set -e
export CFLAGS="$RPM_OPT_FLAGS"

_build() {
    local configure_add configure_env cc_opt ld_opt make_target=modules objs_dir

    local arg; for arg in "$@"; do
        case "$arg" in
            cc_opt=*)
                cc_opt="${arg#cc_opt=}"
                ;;
            configure_add=*)
                configure_add="${arg#configure_add=}"
                ;;
            configure_env=*)
                configure_env=${arg#configure_env=}
                ;;
            objs_dir=*)
                objs_dir="${arg#objs_dir=}"
                ;;
            ld_opt=*)
                ld_opt="${arg#ld_opt=}"
                ;;
            make_target=*)
                make_target=${arg#make_target=}
                ;;
        esac
    done

    local configure_args="
    --prefix=/etc/angie
    --conf-path=/etc/angie/angie.conf
    --error-log-path=%{_var}/log/angie/error.log
    --http-log-path=%{_var}/log/angie/access.log
    --lock-path=/run/angie.lock
    --modules-path=/usr/lib/angie/modules
    --pid-path=/run/angie.pid
    --sbin-path=/usr/sbin/angie
    --http-acme-client-path=%{_var}/lib/angie/acme
    --http-client-body-temp-path=%{_var}/cache/angie/client_temp
    --http-fastcgi-temp-path=%{_var}/cache/angie/fastcgi_temp
    --http-proxy-temp-path=%{_var}/cache/angie/proxy_temp
    --http-scgi-temp-path=%{_var}/cache/angie/scgi_temp
    --http-uwsgi-temp-path=%{_var}/cache/angie/uwsgi_temp
    --user=angie
    --group=angie
    --with-file-aio
    --with-http_acme_module
    --with-http_addition_module
    --with-http_auth_request_module
    --with-http_dav_module
    --with-http_flv_module
    --with-http_gunzip_module
    --with-http_gzip_static_module
    --with-http_mp4_module
    --with-http_random_index_module
    --with-http_realip_module
    --with-http_secure_link_module
    --with-http_slice_module
    --with-http_ssl_module
    --with-http_stub_status_module
    --with-http_sub_module
    --with-http_v2_module
    --with-http_v3_module
    --with-mail
    --with-mail_ssl_module
    --with-stream
    --with-stream_mqtt_preread_module
    --with-stream_rdp_preread_module
    --with-stream_realip_module
    --with-stream_ssl_module
    --with-stream_ssl_preread_module
    --with-threads
    $configure_add
    --feature-cache=../angie-feature-cache
    "

    [ -n "$cc_opt" ] && configure_args="$configure_args --with-cc-opt=\"$cc_opt\""

    # always prepend LDFLAGS (if set) to --with-ld-opt
    if [ -n "$RPM_LD_FLAGS" ]; then
        [ -n "$ld_opt" ] && ld_opt="$RPM_LD_FLAGS $ld_opt" || ld_opt="$RPM_LD_FLAGS"
    fi
    [ -n "$ld_opt" ] && configure_args="$configure_args --with-ld-opt=\"$ld_opt\""

    (
        [ -f Makefile ] && make clean
        eval env $configure_env ./configure $configure_args
        [ -n "$objs_dir" ] && mkdir "$objs_dir"
        if [ $make_target != none ]; then
            make %{?_smp_mflags} $make_target
            if [ -n "$objs_dir" ]; then
                cp -p objs/*.so "$objs_dir"
            fi
        fi
    )

    (
        cd ../angie-debug
        [ -f Makefile ] && make clean
        eval env $configure_env ./configure $configure_args --with-debug
        if [ $make_target != none ]; then
            make %{?_smp_mflags} $make_target
            if [ -n "$objs_dir" ]; then
                for so in $(cd objs && ls *.so); do
                    cp -p objs/$so ../%{name}-%{version}/"$objs_dir"/${so%%.so}-debug.so
                done
            fi
        fi
    )
}

(
    cd ../wasm-micro-runtime-WAMR-1.3.2
    mkdir .build && cd .build
    cmake -DCMAKE_INSTALL_PREFIX=%{_builddir}/sandbox ..
    make -j2 install
)

(
    cp -Rp ../wasmtime-v25.0.0-x86_64-linux-c-api/include/* \
           %{_builddir}/sandbox/include
    cp -Rp ../wasmtime-v25.0.0-x86_64-linux-c-api/lib/libwasmtime.a \
           %{_builddir}/sandbox/lib
)

_build configure_add="--add-dynamic-module=../angie-wasm/ngx_wamr_module" \
       cc_opt="-I%{_builddir}/sandbox/include" \
       ld_opt="-L%{_builddir}/sandbox/lib -lvmlib -lm" \
       objs_dir=module-wamr

cp %{_sourcedir}/README-module-wamr module-wamr/README

_build configure_add="--add-dynamic-module=../angie-wasm/ngx_wasmtime_module" \
       cc_opt="-I%{_builddir}/sandbox/include" \
       ld_opt="-L%{_builddir}/sandbox/lib -lwasmtime -lm" \
       objs_dir=module-wasmtime

cp %{_sourcedir}/README-module-wasmtime module-wasmtime/README

_build configure_add="--add-dynamic-module=../angie-wasm/ngx_wasm_module
                      --add-dynamic-module=../angie-wasm/ngx_http_wasm_event_module
                      --add-dynamic-module=../angie-wasm/ngx_http_wasm_host_module
                      --add-dynamic-module=../angie-wasm/ngx_http_wasm_vars_module
                      --add-dynamic-module=../angie-wasm/ngx_http_wasm_content_module
                      --add-dynamic-module=../angie-wasm/ngx_http_wasm_filter_module" \
       objs_dir=module-wasm

cp %{_sourcedir}/README-module-wasm module-wasm/README

_build \
    make_target=build

%install
rm -Rf %{buildroot}
mkdir -p %{buildroot}

install -dm 755 \
    %{buildroot}%{_sysconfdir}/angie \
    %{buildroot}%{_var}/cache/angie \
    %{buildroot}%{_var}/lib/angie \
    %{buildroot}%{_libdir}/angie/modules

install -Dm 755 objs/angie %{buildroot}%{_sbindir}/angie-nodebug
install -Dm 755 ../angie-debug/objs/angie %{buildroot}%{_sbindir}/angie-debug
ln -fs angie-nodebug %{buildroot}%{_sbindir}/angie

install -Dm 644 objs/angie.8 %{buildroot}%{_mandir}/man8/angie.8

install -dm 755 %{buildroot}%{_datadir}/angie/html
install -Dm 644 html/* -t %{buildroot}%{_datadir}/angie/html

install -Dm 644 conf/fastcgi.conf         -t %{buildroot}%{_sysconfdir}/angie
install -Dm 644 conf/fastcgi_params       -t %{buildroot}%{_sysconfdir}/angie
install -Dm 644 conf/mime.types           -t %{buildroot}%{_sysconfdir}/angie
install -Dm 644 conf/prometheus_all.conf  -t %{buildroot}%{_sysconfdir}/angie
install -Dm 644 conf/scgi_params          -t %{buildroot}%{_sysconfdir}/angie
install -Dm 644 conf/uwsgi_params         -t %{buildroot}%{_sysconfdir}/angie

install -Dm 644 %{_sourcedir}/angie.conf      %{buildroot}%{_sysconfdir}/angie/angie.conf
install -Dm 644 %{_sourcedir}/default.conf    %{buildroot}%{_sysconfdir}/angie/http.d/default.conf
install -Dm 644 %{_sourcedir}/example.conf    %{buildroot}%{_sysconfdir}/angie/stream.d/example.conf
install -Dm 644 %{_sourcedir}/angie.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/angie
install -Dm 644 %{_sourcedir}/angie.service   %{buildroot}%{_unitdir}/angie.service
install -Dm 755 %{_sourcedir}/angie.upgrade   %{buildroot}%{_libexecdir}/initscripts/legacy-actions/angie/upgrade

ln -fs ../../usr/lib64/angie/modules %{buildroot}%{_sysconfdir}/angie/modules

install -Dm 755 module-wasm/ngx_*.so \
    -t %{buildroot}%{_libdir}/angie/modules
install -Dm 755 module-wamr/ngx_wamr_module*.so \
    -t %{buildroot}%{_libdir}/angie/modules
install -Dm 755 module-wasmtime/ngx_wasmtime_module*.so \
    -t %{buildroot}%{_libdir}/angie/modules

%clean
rm -Rf %{buildroot}

%files
%{_sbindir}/angie
%{_sbindir}/angie-debug
%{_sbindir}/angie-nodebug

%dir %{_sysconfdir}/angie
%dir %{_sysconfdir}/angie/http.d
%dir %{_sysconfdir}/angie/stream.d

%config(noreplace) %{_sysconfdir}/angie/angie.conf
%config(noreplace) %{_sysconfdir}/angie/http.d/default.conf
%config(noreplace) %{_sysconfdir}/angie/stream.d/example.conf
%config(noreplace) %{_sysconfdir}/angie/fastcgi.conf
%config(noreplace) %{_sysconfdir}/angie/fastcgi_params
%config(noreplace) %{_sysconfdir}/angie/mime.types
%config(noreplace) %{_sysconfdir}/angie/prometheus_all.conf
%config(noreplace) %{_sysconfdir}/angie/scgi_params
%config(noreplace) %{_sysconfdir}/angie/uwsgi_params
%config(noreplace) %{_sysconfdir}/logrotate.d/angie

%{_sysconfdir}/angie/modules

%dir %{_datadir}/angie
%{_datadir}/angie/html

%doc CHANGES CHANGES.ru README
%license LICENSE

%dir %{_libdir}/angie
%dir %{_libdir}/angie/modules
%dir %{_libexecdir}/initscripts/legacy-actions/angie
%{_libexecdir}/initscripts/legacy-actions/angie/upgrade

%{_mandir}/man8/angie.8*

%{_unitdir}/angie.service

%dir %{_var}/cache/angie
%dir %{_var}/lib/angie

%pre
# install:1, upgrade:2
if [ $1 -eq 1 ]; then
	if ! getent group angie >/dev/null; then
		groupadd -r angie
	fi

	if ! getent passwd angie >/dev/null; then
		useradd -c Angie -d %{_var}/cache/angie -g angie -r -s /sbin/nologin angie
	fi
fi

%post
# install:1, upgrade:2
%systemd_post angie.service

if [ ! -e %{_var}/log/angie ]; then
	install -d -m 755 -o root -g root %{_var}/log/angie || :
fi
if [ ! -e %{_var}/lib/angie/acme ]; then
    install -d -m 700 -o root -g root %{_var}/lib/angie/acme || :
fi

if [ $1 -eq 1 ]; then
	cat <<EOM
----------------------------------------------------------------------

Thanks for using Angie!

Please find the official documentation for Angie here:
* https://en.angie.software/angie/docs/

----------------------------------------------------------------------
EOM
fi

%preun
# uninstall:0, upgrade:1
%systemd_preun angie.service
if [ $1 -eq 0 ]; then
	if [ -d %{_var}/lib/angie/acme ]; then
		rmdir %{_var}/lib/angie/acme 2>/dev/null || :
	fi
	if [ -d %{_var}/log/angie ]; then
		rmdir %{_var}/log/angie 2>/dev/null || :
	fi
fi

%postun
# uninstall:0, upgrade:1
%systemd_postun angie.service

if [ $1 -eq 1 ]; then
	if systemctl is-active angie >/dev/null 2>&1; then
		service angie upgrade >/dev/null 2>&1 || \
		    echo "Binary upgrade failed, please check error.log"
	fi
fi
%package module-wamr
Summary:           WAMR run-time for Angie Wasm dynamic module
Requires:          angie = %{version}-%{release}

%description module-wamr
WebAssembly Micro Runtime (WAMR) is a lightweight standalone WebAssembly (Wasm) runtime with small footprint,
high performance and highly configurable features for applications cross from embedded, IoT,
edge to Trusted Execution Environment (TEE), smart contract, cloud native and so on.

%files module-wamr
%{_libdir}/angie/modules/ngx_wamr_module.so
%{_libdir}/angie/modules/ngx_wamr_module-debug.so

%doc     module-wamr/README
%license LICENSE

%post module-wamr
if [ $1 -eq 1 ]; then
  cat <<BANNER
----------------------------------------------------------------------

The WAMR run-time for Angie Wasm dynamic module has been installed.
To enable this module, add the following to /etc/angie/angie.conf
and reload angie:

    load_module modules/ngx_wamr_module.so;

Please refer to the module documentation for further details:
https://github.com/bytecodealliance/wasm-micro-runtime
https://git.angie.software/web-server/angie-wasm

----------------------------------------------------------------------
BANNER
fi

%package module-wasmtime
Summary:           Wasmtime run-time for Angie Wasm dynamic module
Requires:          angie = %{version}-%{release}

%description module-wasmtime
Wasmtime is built on the optimizing Cranelift code generator to quickly generate high-quality machine
code either at runtime or ahead-of-time. Wasmtime is optimized for efficient instantiation,
low-overhead calls between the embedder and wasm, and scalability of concurrent instances.

%files module-wasmtime
%{_libdir}/angie/modules/ngx_wasmtime_module.so
%{_libdir}/angie/modules/ngx_wasmtime_module-debug.so

%doc     module-wasmtime/README
%license LICENSE

%post module-wasmtime
if [ $1 -eq 1 ]; then
  cat <<BANNER
----------------------------------------------------------------------

The Wasmtime run-time for Angie Wasm dynamic module has been installed.
To enable this module, add the following to /etc/angie/angie.conf
and reload angie:

    load_module modules/ngx_wasmtime_module.so;

Please refer to the module documentation for further details:
https://github.com/bytecodealliance/wasmtime
https://git.angie.software/web-server/angie-wasm

----------------------------------------------------------------------
BANNER
fi

%package module-wasm
Summary:           Angie Webasm  dynamic module
Requires:          angie = %{version}-%{release}
Requires:          angie-module-wasmtime = %{version}-%{release}

%description module-wasm
Module allows to run Web Assembly Angie extensions in Angie

%files module-wasm
%{_libdir}/angie/modules/ngx_http_wasm_content_module.so
%{_libdir}/angie/modules/ngx_http_wasm_content_module-debug.so
%{_libdir}/angie/modules/ngx_http_wasm_event_module.so
%{_libdir}/angie/modules/ngx_http_wasm_event_module-debug.so
%{_libdir}/angie/modules/ngx_http_wasm_filter_module.so
%{_libdir}/angie/modules/ngx_http_wasm_filter_module-debug.so
%{_libdir}/angie/modules/ngx_http_wasm_host_module.so
%{_libdir}/angie/modules/ngx_http_wasm_host_module-debug.so
%{_libdir}/angie/modules/ngx_http_wasm_vars_module.so
%{_libdir}/angie/modules/ngx_http_wasm_vars_module-debug.so
%{_libdir}/angie/modules/ngx_wasm_core_module.so
%{_libdir}/angie/modules/ngx_wasm_core_module-debug.so
%{_libdir}/angie/modules/ngx_wasm_module.so
%{_libdir}/angie/modules/ngx_wasm_module-debug.so

%doc     module-wasm/README
%license LICENSE

%post module-wasm
if [ $1 -eq 1 ]; then
  cat <<BANNER
----------------------------------------------------------------------

The Webasm dynamic module for Angie has been installed.
To enable this module, add the following to /etc/angie/angie.conf
and reload angie:

    load_module modules/ngx_wasm_module.so;
    load_module modules/ngx_wasm_core_module.so;
    load_module modules/ngx_http_wasm_host_module.so;
    load_module modules/ngx_http_wasm_content_module.so;
    load_module modules/ngx_http_wasm_event_module.so;
    load_module modules/ngx_http_wasm_filter_module.so;
    load_module modules/ngx_http_wasm_vars_module.so;
    load_module modules/ngx_wasmtime_module.so;

Please refer to the module documentation for further details:
https://git.angie.software/web-server/angie-wasm

----------------------------------------------------------------------
BANNER
fi
%changelog
* Thu Sep 19 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.7.0-1
- Release 1.7.0
- Updated angie-module-opentracing to 0.36.0
- Updated angie-module-lua to 0.10.27

* Fri Aug 16 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.6.2-1
- Release 1.6.2

* Wed Aug 07 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.6.1-1
- Release 1.6.1
- Updated angie-module-opentracing to v0.35.3
- Updated angie-module-zstd to f4ba115e0b0eaecde545e5f37db6aa18917d8f4b

* Thu Jun 27 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.6.0-1
- Release 1.6.0
- Updated angie-module-auth-jwt to 0.7.0
- Updated angie-module-auth-ldap to 241200eac8e4acae74d353291bd27f79e5ca3dc4
- Updated angie-module-jwt to 3.4.1
- Updated angie-module-keyval to 0.3.0
- Updated angie-module-njs to 0.8.5

* Mon Jun 03 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.5.2-1
- Release 1.5.2
- Updated angie-module-opentracing to 0.35.2

* Wed May 15 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.5.1-1
- Release 1.5.1

* Wed Apr 24 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.5.0-3
- Added angie-module-vts

* Tue Apr 16 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.5.0-2
- Added angie-module-zstd
- Updated angie-module-njs to 0.8.4

* Mon Mar 25 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.5.0-1
- Release 1.5.0
- Added angie-module-otel
- Updated angie-module-jwt to v3.4.0

* Thu Feb 15 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.4.1-1
- Release 1.4.1
- Added angie-module-dynamic-limit-req
- Updated angie-module-njs to 0.8.3
- Updated angie-module-vod to 1.33

* Mon Jan 22 2024 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.4.0-3
- Added angie-module-zip ver. 1.3.0
- Updated angie-module-auth-jwt to 0.6.0
- Updated angie-module-headers-more to 0.37
- Updated angie-module-lua to 0.10.26
- Updated angie-module-modsecurity to 3.0.11

* Tue Dec 12 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.4.0-2
- Added missed distribution file for angie-module-auth-ldap into SRPM

* Mon Dec 11 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.4.0-1
- Release 1.4.0
- Added angie-module-auth-ldap
- Updated angie-module-auth-jwt to 0.4.0
- Updated angie-module-headers-more to 0.36
- Updated angie-module-ndk to 0.3.3
- Updated angie-module-opentracing to 0.33.0

* Fri Dec 1 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.3.2-2
- Added angie-module-modsecurity

* Wed Nov 22 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.3.2-1
- Release 1.3.2

* Mon Nov 13 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.3.1-3
- Added angie-module-testcookie
- Updated angie-module-headers-more to 0.35
- Updated angie-module-njs to 0.8.2
- Updated angie-module-vod to 1.32

* Thu Oct 26 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.3.1-2
- Added angie-module-opentracing

* Tue Oct 17 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.3.1-1
- Release 1.3.1

* Thu Sep 21 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.3.0-2
- Moved angie/http.d/prometheus.conf.sample to angie/prometheus_all.conf

* Tue Sep 19 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.3.0-1
- Release 1.3.0
- Updated angie-module-keyval to 0.2.0
- Updated angie-module-lua to 0.10.25
- Updated angie-module-njs to 0.8.1

* Wed Aug 30 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.2.0-5
- Added filetrigger for ALT Linux

* Thu Aug 17 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.2.0-4
- Added angie-module-enhanced-memcached
- Added angie-module-eval

* Thu Jul 27 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.2.0-3
- Added angie-module-auth-jwt
- Updated angie-module-jwt to 3.2.2

* Mon Jul 17 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.2.0-2
- Added angie-module-cache-purge
- Added angie-module-echo
- Added angie-module-keyval
- Added angie-module-postgresql
- Updated angie-module-njs to 0.8.0
- Updated angie-module-njs-cli to 0.8.0

* Tue May 30 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.2.0-1
- Release 1.2.0
- Added angie-module-lua
- Added angie-module-redis2

* Wed May 10 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.1.0-3
- Added angie-module-jwt
- Added angie-module-subs
- Added angie-module-upload
- Added angie-module-vod
- Updated angie-module-njs to 0.7.12
- Updated angie-module-njs-cli to 0.7.12

* Fri Mar 10 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.1.0-2
- Added angie-module-auth-spnego
- Added angie-module-brotli
- Added angie-module-dav-ext
- Added angie-module-headers-more
- Added angie-module-ndk
- Added angie-module-rtmp
- Added angie-module-set-misc
- Updated angie-module-njs to 0.7.11
- Separate angie-module-njs-cli package

* Wed Jan 25 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.1.0-1
- Release 1.1.0

* Fri Jan 13 2023 Release Engineering Team <devops@tech.wbsrv.ru> - angie-1.0.0-1
- new version 1.0.0
